@@ -12,9 +12,11 @@ import socket
 
 from netaddr import IPAddress, IPNetwork, IPGlob, IPRange, IPSet
 
+from pyramid.compat import integer_types, string_types
+
 #  This is used to split a string on an optional comma,
 #  followed by any amount of whitespace.
-_COMMA_OR_WHITESPACE = re.compile(r",?\s*")
+_COMMA_OR_WHITESPACE = re.compile(r"(?:,\s*)|(?:\s+)")
 
 
 def get_ip_address(request, proxies=None):
@@ -93,10 +95,10 @@ def make_ip_set(ipaddrs):
     if ipaddrs is None:
         return IPSet()
     # Integers represent a single address.
-    if isinstance(ipaddrs, (int, long)):
+    if isinstance(ipaddrs, integer_types):
         return IPSet((IPAddress(ipaddrs),))
     # Strings get parsed as per parse_ip_set
-    if isinstance(ipaddrs, basestring):
+    if isinstance(ipaddrs, string_types):
         return parse_ip_set(ipaddrs)
     # Other netaddr types can be converted into a set.
     if isinstance(ipaddrs, (IPAddress, IPNetwork)):
@@ -164,5 +166,9 @@ def get_local_ip_addresses():
     """Iterator yielding all local IP addresses on the machine."""
     # XXX: how can we enumerate all interfaces on the machine?
     # I don't really want to shell out to `ifconfig`
-    for addr in socket.gethostbyname_ex(socket.gethostname())[2]:
-        yield IPAddress(addr)
+    # Sadly this is not guaranteed to succeed.
+    try:
+        for addr in socket.gethostbyname_ex(socket.gethostname())[2]:
+            yield IPAddress(addr)
+    except socket.gaierror:
+        pass
